Page MenuHomePhabricator

D17995.id43272.diff
No OneTemporary

D17995.id43272.diff

diff --git a/src/applications/calendar/view/PHUIUserAvailabilityView.php b/src/applications/calendar/view/PHUIUserAvailabilityView.php
--- a/src/applications/calendar/view/PHUIUserAvailabilityView.php
+++ b/src/applications/calendar/view/PHUIUserAvailabilityView.php
@@ -29,7 +29,7 @@
$away_tag = id(new PHUITagView())
->setType(PHUITagView::TYPE_SHADE)
- ->setShade($color)
+ ->setColor($color)
->setName($name)
->setDotColor($color);
diff --git a/src/applications/conpherence/controller/ConpherenceController.php b/src/applications/conpherence/controller/ConpherenceController.php
--- a/src/applications/conpherence/controller/ConpherenceController.php
+++ b/src/applications/conpherence/controller/ConpherenceController.php
@@ -71,7 +71,7 @@
if (strlen($data['topic'])) {
$topic = id(new PHUITagView())
->setName($data['topic'])
- ->setShade(PHUITagView::COLOR_VIOLET)
+ ->setColor(PHUITagView::COLOR_VIOLET)
->setType(PHUITagView::TYPE_SHADE)
->addClass('conpherence-header-topic');
$header->addTag($topic);
diff --git a/src/applications/differential/constants/DifferentialRevisionStatus.php b/src/applications/differential/constants/DifferentialRevisionStatus.php
--- a/src/applications/differential/constants/DifferentialRevisionStatus.php
+++ b/src/applications/differential/constants/DifferentialRevisionStatus.php
@@ -65,7 +65,7 @@
$tag = id(new PHUITagView())
->setName($status_name)
->setIcon(self::getRevisionStatusIcon($status))
- ->setShade(self::getRevisionStatusColor($status))
+ ->setColor(self::getRevisionStatusColor($status))
->setType(PHUITagView::TYPE_SHADE);
return $tag;
diff --git a/src/applications/files/controller/PhabricatorFileInfoController.php b/src/applications/files/controller/PhabricatorFileInfoController.php
--- a/src/applications/files/controller/PhabricatorFileInfoController.php
+++ b/src/applications/files/controller/PhabricatorFileInfoController.php
@@ -44,7 +44,7 @@
if ($ttl !== null) {
$ttl_tag = id(new PHUITagView())
->setType(PHUITagView::TYPE_SHADE)
- ->setShade(PHUITagView::COLOR_YELLOW)
+ ->setColor(PHUITagView::COLOR_YELLOW)
->setName(pht('Temporary'));
$header->addTag($ttl_tag);
}
@@ -53,7 +53,7 @@
if ($partial) {
$partial_tag = id(new PHUITagView())
->setType(PHUITagView::TYPE_SHADE)
- ->setShade(PHUITagView::COLOR_ORANGE)
+ ->setColor(PHUITagView::COLOR_ORANGE)
->setName(pht('Partial Upload'));
$header->addTag($partial_tag);
}
diff --git a/src/applications/harbormaster/view/HarbormasterUnitSummaryView.php b/src/applications/harbormaster/view/HarbormasterUnitSummaryView.php
--- a/src/applications/harbormaster/view/HarbormasterUnitSummaryView.php
+++ b/src/applications/harbormaster/view/HarbormasterUnitSummaryView.php
@@ -56,7 +56,7 @@
$tag = id(new PHUITagView())
->setType(PHUITagView::TYPE_SHADE)
- ->setShade($tag_color)
+ ->setColor($tag_color)
->setIcon($tag_icon)
->setName($tag_text);
diff --git a/src/applications/maniphest/constants/ManiphestTaskStatus.php b/src/applications/maniphest/constants/ManiphestTaskStatus.php
--- a/src/applications/maniphest/constants/ManiphestTaskStatus.php
+++ b/src/applications/maniphest/constants/ManiphestTaskStatus.php
@@ -97,7 +97,7 @@
->setName($name)
->setIcon($icon)
->setType(PHUITagView::TYPE_SHADE)
- ->setShade($color);
+ ->setColor($color);
return $tag;
}
diff --git a/src/applications/owners/engineextension/PhabricatorOwnersHovercardEngineExtension.php b/src/applications/owners/engineextension/PhabricatorOwnersHovercardEngineExtension.php
--- a/src/applications/owners/engineextension/PhabricatorOwnersHovercardEngineExtension.php
+++ b/src/applications/owners/engineextension/PhabricatorOwnersHovercardEngineExtension.php
@@ -64,7 +64,7 @@
if ($package->isArchived()) {
$tag = id(new PHUITagView())
->setName(pht('Archived'))
- ->setShade(PHUITagView::COLOR_INDIGO)
+ ->setColor(PHUITagView::COLOR_INDIGO)
->setType(PHUITagView::TYPE_OBJECT);
$hovercard->addTag($tag);
}
diff --git a/src/applications/people/view/PhabricatorUserCardView.php b/src/applications/people/view/PhabricatorUserCardView.php
--- a/src/applications/people/view/PhabricatorUserCardView.php
+++ b/src/applications/people/view/PhabricatorUserCardView.php
@@ -85,7 +85,7 @@
->setType(PHUITagView::TYPE_SHADE);
if ($tag_shade !== null) {
- $tag->setShade($tag_shade);
+ $tag->setColor($tag_shade);
}
$body = array();
diff --git a/src/applications/project/controller/PhabricatorProjectBoardViewController.php b/src/applications/project/controller/PhabricatorProjectBoardViewController.php
--- a/src/applications/project/controller/PhabricatorProjectBoardViewController.php
+++ b/src/applications/project/controller/PhabricatorProjectBoardViewController.php
@@ -331,7 +331,7 @@
$count_tag = id(new PHUITagView())
->setType(PHUITagView::TYPE_SHADE)
- ->setShade(PHUITagView::COLOR_BLUE)
+ ->setColor(PHUITagView::COLOR_BLUE)
->addSigil('column-points')
->setName(
javelin_tag(
diff --git a/src/applications/project/query/PhabricatorProjectSearchEngine.php b/src/applications/project/query/PhabricatorProjectSearchEngine.php
--- a/src/applications/project/query/PhabricatorProjectSearchEngine.php
+++ b/src/applications/project/query/PhabricatorProjectSearchEngine.php
@@ -211,7 +211,7 @@
$options[$color] = array(
id(new PHUITagView())
->setType(PHUITagView::TYPE_SHADE)
- ->setShade($color)
+ ->setColor($color)
->setName($name),
);
}
diff --git a/src/applications/project/view/ProjectBoardTaskCard.php b/src/applications/project/view/ProjectBoardTaskCard.php
--- a/src/applications/project/view/ProjectBoardTaskCard.php
+++ b/src/applications/project/view/ProjectBoardTaskCard.php
@@ -100,7 +100,7 @@
if ($points !== null) {
$points_tag = id(new PHUITagView())
->setType(PHUITagView::TYPE_SHADE)
- ->setShade(PHUITagView::COLOR_GREY)
+ ->setColor(PHUITagView::COLOR_GREY)
->setSlimShady(true)
->setName($points)
->addClass('phui-workcard-points');
diff --git a/src/applications/search/query/PhabricatorFulltextToken.php b/src/applications/search/query/PhabricatorFulltextToken.php
--- a/src/applications/search/query/PhabricatorFulltextToken.php
+++ b/src/applications/search/query/PhabricatorFulltextToken.php
@@ -64,7 +64,7 @@
$tag = id(new PHUITagView())
->setType(PHUITagView::TYPE_SHADE)
- ->setShade($shade)
+ ->setColor($shade)
->setName($token->getValue());
if ($tip !== null) {
diff --git a/src/applications/uiexample/examples/PHUITagExample.php b/src/applications/uiexample/examples/PHUITagExample.php
--- a/src/applications/uiexample/examples/PHUITagExample.php
+++ b/src/applications/uiexample/examples/PHUITagExample.php
@@ -187,12 +187,12 @@
foreach ($outlines as $outline) {
$tags[] = id(new PHUITagView())
->setType(PHUITagView::TYPE_OUTLINE)
- ->setShade($outline)
+ ->setColor($outline)
->setName($outline);
$tags[] = hsprintf(' ');
$tags[] = id(new PHUITagView())
->setType(PHUITagView::TYPE_OUTLINE)
- ->setShade($outline)
+ ->setColor($outline)
->setSlimShady(true)
->setName($outline);
$tags[] = hsprintf('<br /><br />');
diff --git a/src/infrastructure/diff/view/PHUIDiffInlineCommentDetailView.php b/src/infrastructure/diff/view/PHUIDiffInlineCommentDetailView.php
--- a/src/infrastructure/diff/view/PHUIDiffInlineCommentDetailView.php
+++ b/src/infrastructure/diff/view/PHUIDiffInlineCommentDetailView.php
@@ -148,7 +148,7 @@
->setType(PHUITagView::TYPE_SHADE)
->setName(pht('Unsubmitted'))
->setSlimShady(true)
- ->setShade(PHUITagView::COLOR_RED)
+ ->setColor(PHUITagView::COLOR_RED)
->addClass('mml inline-draft-text');
}
@@ -383,7 +383,7 @@
->setType(PHUITagView::TYPE_SHADE)
->setName(pht('Author'))
->setSlimShady(true)
- ->setShade(PHUITagView::COLOR_YELLOW)
+ ->setColor(PHUITagView::COLOR_YELLOW)
->addClass('mml');
}
}
diff --git a/src/infrastructure/markup/rule/PhabricatorNavigationRemarkupRule.php b/src/infrastructure/markup/rule/PhabricatorNavigationRemarkupRule.php
--- a/src/infrastructure/markup/rule/PhabricatorNavigationRemarkupRule.php
+++ b/src/infrastructure/markup/rule/PhabricatorNavigationRemarkupRule.php
@@ -60,7 +60,7 @@
$tag = id(new PHUITagView())
->setType(PHUITagView::TYPE_SHADE)
- ->setShade($item_color)
+ ->setColor($item_color)
->setName($item_name);
if ($item['icon']) {
diff --git a/src/view/phui/PHUIHeaderView.php b/src/view/phui/PHUIHeaderView.php
--- a/src/view/phui/PHUIHeaderView.php
+++ b/src/view/phui/PHUIHeaderView.php
@@ -131,7 +131,7 @@
$tag = id(new PHUITagView())
->setName($name)
->setIcon($icon)
- ->setShade($color)
+ ->setColor($color)
->setType(PHUITagView::TYPE_SHADE);
return $this->addProperty(self::PROPERTY_STATUS, $tag);
diff --git a/src/view/phui/PHUITagView.php b/src/view/phui/PHUITagView.php
--- a/src/view/phui/PHUITagView.php
+++ b/src/view/phui/PHUITagView.php
@@ -57,8 +57,14 @@
return $this;
}
/* Deprecated, use setColor */
public function setShade($shade) {
+ phlog(
+ pht('Deprecated call to setShade(), use setColor() instead.'));
$this->color = $shade;
return $this;
}
@@ -57,8 +57,14 @@
return $this;
}
- /* Deprecated, use setColor */
+ /**
+ * This method has been deprecated, use @{method:setColor} instead.
+ *
+ * @deprecated
+ */
public function setShade($shade) {

File Metadata

Mime Type
text/plain
Expires
Fri, Mar 21, 7:55 AM (3 h, 20 m ago)
Storage Engine
blob
Storage Format
Encrypted (AES-256-CBC)
Storage Handle
7689115
Default Alt Text
D17995.id43272.diff (9 KB)

Event Timeline